@@ -18,6 +18,16 @@ INSTALLED_APPS = (
     'django.contrib.staticfiles',
 )
 
+MIDDLEWARE_CLASSES = (
+    'django.contrib.sessions.middleware.SessionMiddleware',
+    'django.middleware.common.CommonMiddleware',
+    'django.middleware.csrf.CsrfViewMiddleware',
+    'django.contrib.auth.middleware.AuthenticationMiddleware',
+    'django.contrib.messages.middleware.MessageMiddleware',
+    'django.middleware.clickjacking.XFrameOptionsMiddleware',
+    'proxy_server.middleware.DisableCSRF',
+)
+
 SECRET_KEY = 'askjfadl#aksjdkasdl!aksjfkadfl)'
 
 BACKEND_HOST = '0.0.0.0'
@@ -26,4 +36,4 @@ BACKEND_PORT = '8001'
 ROOT_URLCONF = 'urls'
 
 PROXY_API_KEYS = ['^ugfp@+cw!+se1b8kw%!23(sbrzk8f!uzrhqp$s)@67g9f1tdj', 'http://127.0.0.1:8001/']
-PROXY_TOKEN_VALIDATION_SERVICE = 'tests.rest_api_connection.renew_session'
\ No newline at end of file
+PROXY_TOKEN_VALIDATION_SERVICE = 'tests.rest_api_connection.renew_session'
